package com.zd.chemical.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.zd.common.core.web.domain.ResultData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zd.common.log.annotation.Log;
import com.zd.common.log.enums.BusinessType;
import com.zd.common.security.annotation.PreAuthorize;
import com.zd.chemical.domain.ActApplytaskNode;
import com.zd.chemical.service.IActApplytaskNodeService;
import com.zd.common.core.web.controller.BaseController;
import com.zd.common.core.web.domain.AjaxResult;
import com.zd.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import com.zd.common.core.web.page.TableDataInfo;

/**
 * 化学品申购任务节点Controller
 *
 * @author zd
 * @date 2022-08-17
 */
@RestController
@Api(tags = "【化学品申购任务节点】")
@RequestMapping("/applytaskNode")
public class ActApplytaskNodeController extends BaseController<ActApplytaskNode>
{
    @Autowired
    private IActApplytaskNodeService actApplytaskNodeService;

    /**
     * 查询化学品申购任务节点列表
     */
//    @PreAuthorize(hasPermi = "laboratory:node:list")
    @GetMapping("/list")
    @ApiOperation(value = "查询化学品申购任务节点列表")
    public TableDataInfo<ActApplytaskNode> list(ActApplytaskNode actApplytaskNode)
    {
        startPage();
        List<ActApplytaskNode> list = actApplytaskNodeService.selectActApplytaskNodeList(actApplytaskNode);
        return getDataTable(list);
    }

    /**
     * 导出化学品申购任务节点列表
     */
    @ApiOperation(value = "导出化学品申购任务节点列表")
//    @PreAuthorize(hasPermi = "laboratory:node:export")
    @Log(title = "化学品申购任务节点", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ActApplytaskNode actApplytaskNode) throws IOException
    {
        List<ActApplytaskNode> list = actApplytaskNodeService.selectActApplytaskNodeList(actApplytaskNode);
        ExcelUtil<ActApplytaskNode> util = new ExcelUtil<ActApplytaskNode>(ActApplytaskNode.class);
        util.exportExcel(response, list, "化学品申购任务节点数据");
    }

    /**
     * 获取化学品申购任务节点详细信息
     */
    @ApiOperation(value = "获取化学品申购任务节点详细信息")
//    @PreAuthorize(hasPermi = "laboratory:node:query")
    @GetMapping(value = "/{id}")
    public ResultData<ActApplytaskNode> getInfo(@PathVariable("id") Long id)
    {
        return ResultData.success(actApplytaskNodeService.selectActApplytaskNodeById(id));
    }

    /**
     * 新增化学品申购任务节点
     */
    @ApiOperation(value = "新增化学品申购任务节点")
//    @PreAuthorize(hasPermi = "laboratory:node:add")
    @Log(title = "化学品申购任务节点", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultData add(@RequestBody ActApplytaskNode actApplytaskNode)
    {
        return ResultData.result(actApplytaskNodeService.insertActApplytaskNode(actApplytaskNode));
    }

    /**
     * 修改化学品申购任务节点
     */
    @ApiOperation(value = "修改化学品申购任务节点")
//    @PreAuthorize(hasPermi = "laboratory:node:edit")
    @Log(title = "化学品申购任务节点", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultData edit(@RequestBody ActApplytaskNode actApplytaskNode)
    {
        return  ResultData.result(actApplytaskNodeService.updateActApplytaskNode(actApplytaskNode));
    }

    /**
     * 删除化学品申购任务节点
     */
    @ApiOperation(value = "删除化学品申购任务节点")
//    @PreAuthorize(hasPermi = "laboratory:node:remove")
    @Log(title = "化学品申购任务节点", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResultData remove(@PathVariable Long[] ids)
    {
        return ResultData.result(actApplytaskNodeService.deleteActApplytaskNodeByIds(ids));
    }
}
